#
# spec file for package python-msgpack
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define oldpython python
%{?sle15_python_module_pythons}
Name:           python-msgpack
Version:        1.0.5
Release:        2.3
Summary:        MessagePack (de)serializer
License:        Apache-2.0
URL:            https://github.com/msgpack/msgpack-python
Source:         https://files.pythonhosted.org/packages/source/m/msgpack/msgpack-%{version}.tar.gz
BuildRequires:  %{python_module Cython}
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  python-rpm-macros
# was renamed at 0.5.0
Provides:       python-msgpack-python = %{version}
Obsoletes:      python-msgpack-python < 0.5.0
%ifpython2
Provides:       %{oldpython}-msgpack-python = %{version}
Obsoletes:      %{oldpython}-msgpack-python < 0.5.0
%endif
%python_subpackages

%description
MessagePack (de)serializer for Python.

MessagePack is a binary-based efficient data interchange format that is
focused on high performance. It is like JSON, but very fast and small.

%prep
%setup -q -n msgpack-%{version}

%build
export CFLAGS="%{optflags}"
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%check
%pytest_arch

%files %{python_files}
%doc README.md
%license COPYING
%{python_sitearch}/msgpack
%{python_sitearch}/msgpack-%{version}-py*.egg-info

%changelog
* Mon May  8 2023 Johannes Kastl <kastl@b1-systems.de>
- add sle15_python_module_pythons
* Sun Mar 26 2023 Dirk Müller <dmueller@suse.com>
- update to 1.0.5:
  * Fallback to compiler defines when __BYTE_ORDER is not
    available
  * Fix build error caused by ntohs, ntohl
  * Add python 3.11 wheels
  * fallback: Fix packing multidim memoryview
  * minor type in exception message
* Sun Jun 19 2022 Dirk Müller <dmueller@suse.com>
- update to 1.0.4:
  * Support Python 3.11 (beta)
  * refresh ci settings.
  * Don't define _*ENDIAN macro on Unix.
  * Update setuptools and black
  * Use PyFloat_Pack8() on Python 3.11a7
  * Upgrade black to fix CI
  * Fix Unpacker max_buffer_length handling
  * ci: Update action versions.
* Mon Jan 10 2022 Dirk Müller <dmueller@suse.com>
- update to 1.0.3:
  * add python 3.10 support
  * bugfixes
* Sun Dec 20 2020 Dirk Müller <dmueller@suse.com>
- update to 1.0.2:
  * Python 3.9 support
  * bugfixes
* Tue Mar 31 2020 pgajdos@suse.com
- version update to 1.0.0
  * Remove Python 2 support from the msgpack/_cmsgpack. msgpack/fallback still supports Python 2.
  * Remove encoding option from the Packer and Unpacker.
  * Unpacker: The default value of max_buffer_type is changed to 100MiB.
  * Unpacker: strict_map_key is True by default now.
  * Unpacker: String map keys are interned.
  * Drop old buffer protocol support.
  * Support Timestamp type.
  * Support serializing and decerializing datetime object with tzinfo.
  * Unpacker: Fix Unpacker.read_bytes() in fallback implementation. (#352)
* Thu Mar 12 2020 Tomáš Chvátal <tchvatal@suse.com>
- Fix build without python2
* Fri Sep 20 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.6.2:
  * Support Python 3.8.
  * Update Cython to 0.29.13 for support Python 3.8.
  * Some small optimizations.
* Thu Mar  7 2019 Ondřej Súkup <mimi.vx@gmail.com>
- update to 0.6.1
  * unpackb(data) configures max_*_len options from len(data), instead
    of static default sizes.
  * Unpacker(max_buffer_len=N) configures max_*_len options from N, instead
    of static default sizes.
  * max_bin_len, max_str_len, and max_ext_len are deprecated.
  * unpacker: Default value of input limits are smaller than before to
    avoid DoS attack
  * Unpacker doesn't wrap underlaying ValueError (including UnicodeError)
    into UnpackValueError. If you want to catch all exception during unpack,
    you need to use try ... except Exception with minimum try code block.
  * PackValueError and PackOverflowError are also removed. You need to catch
    normal ValueError and OverflowError.
  * Unpacker has strict_map_key option now. When it is true, only bytes
    and str (unicode in Python 2) are allowed for map keys.
  * Extension modules are merged. There is msgpack._cmsgpack instead
    of msgpack._packer and msgpack._unpacker.
  * Add Unpacker.getbuffer() method.
  * unpacker: msgpack.StackError is raised when input data contains too nested data
  * unpacker: msgpack.FormatError is raised when input data is not valid msgpack format.
* Tue Jan 29 2019 alarrosa@suse.com
- Use %%license
* Thu Mar  1 2018 alarrosa@suse.com
- Update to version 0.5.6 (boo#1123558)
  * Fix fallback.Unpacker.feed() dropped unused data from buffer
  * Resurrect fallback.unpack() and _unpacker.unpack(). They were
    removed at 0.5.5 but it breaks backward compatibility.
- Update to version 0.5.5
  * Fix memory leak in pure Python Unpacker.feed()
  * Fix unpack() didn't support raw option
* Mon Feb 26 2018 alarrosa@suse.com
- Provide also python-msgpack-python in the python2 package to
  be able to obsolete the python2-msgpack-python package correctly.
* Mon Feb 12 2018 dmueller@suse.com
- fix typo in obsoletes
* Tue Feb  6 2018 tbechtold@suse.com
- update to version 0.5.4
  * packer: Use PyUnicode_AsUTF8AndSize() for utf-8 (#272)
  * Fix encoding and unicode_errors (#277)
  * Undeprecate unicode_errors (#278)
  * Packer.pack() reset buffer on exception (#274)
  * Use cython's cast for converting encoding and errors (#279)
  * 0.5.4
  * Add raw_as_bytes option to Unpacker. (#265)
  * s/raw_as_bytes/raw/g (#276)
* Tue Jan 30 2018 jengelh@inai.de
- Strip rheotrics from descriptions.
* Sat Jan 27 2018 dmueller@suse.com
- update to 0.5.1:
  * Package name on PyPI was changed to msgpack from 0.5.
- rename from msgpack-python
* Wed Apr 19 2017 toddrme2178@gmail.com
- Implement single-spec version.
* Tue Nov 15 2016 dmueller@suse.com
- update to 0.4.8
* Sat Oct 17 2015 mc@suse.com
- build conditionally without tests
* Mon Mar 16 2015 hpj@urpla.net
- Update to version 0.4.6
  * fallback.Unpacker: Fix Data corruption when OutOfData. This bug
    only affects "Streaming unpacking."
- Changes from version 0.4.5
  * Fix test failure on pytest 2.3.
  * Fix typos in ChangeLog.
  * Improve README.rst
- Changes from version 0.4.4
  * Fix compile error.
- Changes from version 0.4.3
  * Unpacker may unpack wrong uint32 value on 32bit or LLP64
    environment. (#101)
  * Build failed on Windows Python 2.7.
* Tue Nov 18 2014 toddrme2178@gmail.com
- Update to 0.4.2
  Bugfixes
  - Unpacker doesn't increment refcount of ExtType hook.
  - Packer raises no exception for inputs doesn't fit to msgpack format.
- Update to 0.4.1
  Changes
  - fallback.Unpacker.feed() supports bytearray.
  Bugs fixed
  - Unpacker doesn't increment refcount of hooks. Hooks may be GCed while unpacking.
  - Unpacker may read unfilled internal buffer.
* Sun Dec  8 2013 p.drouand@gmail.com
- Update to version 0.4.0
  + Raises TypeError instead of ValueError when packer receives
    unsupported type.
  + Support New msgpack spec.
- Use download Url as source
- Add python-argparse requirement for SLE11SP3 to get tests working
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Thu May  2 2013 speilicke@suse.com
- Package COPYING and README.rst
- Run testsuite
* Mon Feb 18 2013 alexandre@exatati.com.br
- Update to 0.3.0:
  Incompatible Changes
  - Default value of use_list is True for now. (It was False for
    0.2.x) You should pass it explicitly for compatibility to 0.2.x.
  Changes
  - Pure Python fallback module is added. (thanks to bwesterb)
  - Add .skip() method to Unpacker (thanks to jnothman)
  - Add capturing feature. You can pass the writable object to
    Unpacker.unpack() as a second parameter.
  - Add Packer.pack_array_header and Packer.pack_map_header. These
    methods only pack header of each type.
  - Add autoreset option to Packer (default: True). Packer doesn't
    return packed bytes and clear internal buffer.
  - Add Packer.pack_map_pairs. It packs sequence of pair to map type.
* Mon Jan 14 2013 saschpe@suse.de
- Simplify macro usage
* Fri Jan 11 2013 p.drouand@gmail.com
- Initial python3 support
* Sat Dec 22 2012 alexandre@exatati.com.br
- Update to 0.2.4:
  - Fix SEGV when object_hook or object_pairs_hook raise Exception. (#39)
* Tue Dec 11 2012 alexandre@exatati.com.br
- Update to 0.2.3:
  - Warn when use_list is not specified. It's default value will be
    changed in 0.3.
  - Can't pack subclass of dict.
* Fri Sep 21 2012 alexandre@exatati.com.br
- Update to 0.2.2:
  - Add use_single_float option to Packer. When it is true, packs
    float object in single precision format.
  - unpack() didn't restores gc state when it called with gc
    disabled. unpack() doesn't control gc now instead of restoring
    gc state collectly. User can control gc state when gc cause
    performance issue.
  - Unpacker's read_size option didn't used.
* Mon Aug 20 2012 alexandre@exatati.com.br
- Update to 0.2.1:
  - Add max_buffer_size parameter to Unpacker. It limits internal
    buffer size and allows unpack data from untrusted source safely.
  - Unpacker's buffer reallocation algorithm is less greedy now. It
    cause perforamce derease in rare case but memory efficient and
    don't allocate than max_buffer_size.
  - Fix msgpack didn't work on SPARC Solaris. It was because
    choosing wrong byteorder on compilation time. Use sys.byteorder
    to get correct byte order. Very thanks to Chris Casey for giving
    test environment to me.
* Wed Jun 27 2012 alexandre@exatati.com.br
- Update to 0.2.0:
  - Sorry, no changelog.
* Fri Jun 22 2012 alexandre@exatati.com.br
- Initial package (0.1.13) for openSUSE.
